/* This file is a heavily modified version of the file "sqMacJoystick.c".
 *
 * Modifications by: Ian Piumarta (ian.piumarta@inria.fr)
 *
 * Support for Linux/i386 joysticks contributed by:
 *	J"orn Eyrich <joern@eyrich.org>
 *
 * The original version of this file can be regenerated from the Squeak
 * image by executing:
 *
 * 	InterpreterSupportCode writeMacSourceFiles
 */

#include "sq.h"

#if defined(__linux__) && defined(__i386__)

#include <linux/joystick.h>
#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>

#define FILENAMEBUFLEN 16
#define FILENAMEPREFIX "/dev/js"

static int  joyFileDes  [JS_MAX];
static char filenameBuf [FILENAMEBUFLEN];

static char filenamePrefix[]=FILENAMEPREFIX;

int joystickInit(void)
{
  int i;
  for (i=0; i < JS_MAX; i++)
  {
     sprintf(filenameBuf,"%.16s%d",filenamePrefix,i);
     joyFileDes[i] = open(filenameBuf,O_RDONLY);
  }

  /* exit() will close the file descriptors for us */

  return 1;
}

static struct JS_DATA_TYPE joyStruct;

int joystickRead(int index)
{
  if (index < 0 || index >= JS_MAX || joyFileDes[index-1] == -1)
  {
     return 0;
  }

  if (read(joyFileDes[index-1], &joyStruct, JS_RETURN) == -1)
  {
     return 0;
  }

  /* x/y are 0..255, convert to 0..2047 by shifting left 3 bits */
  return    (                1 << 27)
          | ((joyStruct.buttons & 0x1F) << 22)
          | ((joyStruct.y       & 0xFF) << 14)
          | ((joyStruct.x       & 0xFF) <<  3);

  /*
     the comments in sqMacJoystickAndTablet.c are wrong on two counts:

     1: x and y components in the return word format are switched
     2: x and y values are not -1024..1023, but 0..2047

     (see InputSensor>>joystickXY:)
  */
}


int joystickShutdown(void)
{
  /* exit() will close the file descriptors for us */

  return 0;
}

#else

int joystickInit(void)		{ return 0; }
int joystickRead(int index)	{ return 0; }
int joystickShutdown(void)      { return 0; }

#endif
